"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AirshipStatus = void 0;
const constant_1 = require("@skeldjs/constant");
const InnerShipStatus_1 = require("./InnerShipStatus");
const systems_1 = require("../systems");
/**
 * Represents a room object for the Airship map.
 *
 * See {@link ShipStatusEvents} for events to listen to.
 */
class AirshipStatus extends InnerShipStatus_1.InnerShipStatus {
    constructor(room, spawnType, netid, ownerid, flags, data) {
        super(room, spawnType, netid, ownerid, flags, data);
    }
    getComponent(component) {
        if (component === AirshipStatus) {
            return this.components[0];
        }
        return super.getComponent(component);
    }
    Setup() {
        this.systems = {
            [constant_1.SystemType.Electrical]: new systems_1.SwitchSystem(this, {
                expected: [false, false, false, false, false],
                actual: [false, false, false, false, false],
                brightness: 100,
            }),
            [constant_1.SystemType.Security]: new systems_1.SecurityCameraSystem(this, {
                players: new Set,
            }),
            [constant_1.SystemType.Communications]: new systems_1.HudOverrideSystem(this, {
                sabotaged: false,
            }),
            [constant_1.SystemType.Decontamination]: new systems_1.ElectricalDoorsSystem(this, {
                doors: [],
            }),
            [constant_1.SystemType.Decontamination2]: new systems_1.AutoDoorsSystem(this, {
                dirtyBit: 0,
                doors: [],
            }),
            [constant_1.SystemType.Sabotage]: new systems_1.SabotageSystem(this, {
                cooldown: 0,
            }),
            [constant_1.SystemType.GapRoom]: new systems_1.MovingPlatformSystem(this, {
                target: undefined,
                side: systems_1.MovingPlatformSide.Left,
                useId: 0,
            }),
        };
    }
}
exports.AirshipStatus = AirshipStatus;
AirshipStatus.roomDoors = {
    [constant_1.SystemType.Communications]: [0, 1, 2, 3],
    [constant_1.SystemType.Brig]: [4, 5, 6],
    [constant_1.SystemType.Kitchen]: [7, 8, 9],
    [constant_1.SystemType.MainHall]: [10, 11],
    [constant_1.SystemType.Records]: [12, 13, 14],
    [constant_1.SystemType.Lounge]: [15, 16, 17],
    [constant_1.SystemType.Medical]: [19, 20]
};
//# sourceMappingURL=AirshipStatus.js.map